@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Array;
 {
-  $List::Objects::WithUtils::Role::Array::VERSION = '2.006001';
+  $List::Objects::WithUtils::Role::Array::VERSION = '2.007001';
 }
 use strictures 1;
 
@@ -15,16 +15,18 @@ use Scalar::Util ();
 
 # This (and relevant tests) can disappear if UtilsBy gains XS:
 our $UsingUtilsByXS = 0;
-if (eval {; require List::UtilsBy::XS; 1 } && !$@) {
-  $UsingUtilsByXS = 1;
-  *__sort_by  = *List::UtilsBy::XS::sort_by;
-  *__nsort_by = *List::UtilsBy::XS::nsort_by;
-  *__uniq_by  = *List::UtilsBy::XS::uniq_by;
-} else {
-  require List::UtilsBy;
-  *__sort_by  = *List::UtilsBy::sort_by;
-  *__nsort_by = *List::UtilsBy::nsort_by;
-  *__uniq_by  = *List::UtilsBy::uniq_by;
+{ no warnings 'once';
+  if (eval {; require List::UtilsBy::XS; 1 } && !$@) {
+    $UsingUtilsByXS = 1;
+    *__sort_by  = *List::UtilsBy::XS::sort_by;
+    *__nsort_by = *List::UtilsBy::XS::nsort_by;
+    *__uniq_by  = *List::UtilsBy::XS::uniq_by;
+  } else {
+    require List::UtilsBy;
+    *__sort_by  = *List::UtilsBy::sort_by;
+    *__nsort_by = *List::UtilsBy::nsort_by;
+    *__uniq_by  = *List::UtilsBy::uniq_by;
+  }
 }
 
 =pod
@@ -246,6 +248,11 @@ sub mapval {
   )
 }
 
+sub visit {
+  $_[1]->($_) for @{ $_[0] };
+  $_[0]
+}
+
 sub grep {
   blessed_or_pkg($_[0])->new(
     CORE::grep {; $_[1]->($_) } @{ $_[0] }
@@ -333,6 +340,16 @@ sub natatime {
   }
 }
 
+sub rotator {
+  my @list = @{ $_[0] };
+  my $pos = 0;
+  sub {
+    my $val = $list[$pos++];
+    $pos = 0 if $pos == @list;
+    $val
+  }
+}
+
 sub part {
   my ($self, $code) = @_;
   my @parts;
@@ -520,7 +537,7 @@ Returns the number of elements in the array.
 
 =head3 end
 
-Returns the last index of the array.
+Returns the last index of the array (or -1 if the array is empty).
 
 =head3 is_empty
 
@@ -612,7 +629,7 @@ Returns the array object.
 
 Rotates the array in-place. A direction can be given.
 
-Also see L</rotate>.
+Also see L</rotate>, L</rotator>.
 
 =head3 set
 
@@ -817,7 +834,7 @@ Returns a new array object consisting of the reversed list of elements.
 
 Returns a new array object containing the rotated list.
 
-Also see L</rotate_in_place>.
+Also see L</rotate_in_place>, L</rotator>.
 
 =head3 shuffle
 
@@ -1005,6 +1022,19 @@ Returns an iterator that, when called, produces a list containing the next
 If given a coderef as a second argument, it will be called against each
 bundled group.
 
+=head3 rotator
+
+  my $rot = array(qw/cat sheep mouse/);
+  $rot->();  ## 'cat'
+  $rot->();  ## 'sheep'
+  $rot->();  ## 'mouse'
+
+Returns an iterator that, when called, produces the next element in the array;
+when there are no elements left, the iterator returns to the start of the
+array.
+
+See also L</rotate>, L</rotate_in_place>.
+
 =head3 reduce
 
   my $sum = array(1,2,3)->reduce(sub { $_[0] + $_[1] });
@@ -1012,6 +1042,15 @@ bundled group.
 Reduces the array by calling the given subroutine for each element of the
 list. See L<List::Util/"reduce">.
 
+=head3 visit
+
+  $arr->visit(sub { warn "array contains: $_" });
+
+Executes the given subroutine against each element sequentially; in practice
+this is much like L</map>, except the return value is thrown away.
+
+Returns the original array object.
+
 =head2 Methods that sort the list
 
 =head3 sort
